Public PocketIC-oriented test utilities for projects that use Canic.
This crate is intended for host-side test environments (for example via PocketIC) and provides generic helpers such as stable dummy principals, PocketIC wrappers, standalone non-root canister fixtures, generic prebuilt wasm install helpers, retry helpers for PocketIC install throttling, and cached baseline primitives.
Modules
- artifacts
- Host-side artifact discovery and build helpers for PocketIC tests.
- pic
- PocketIC wrapper and fixture helpers for host-side Canic tests.
Structs
- Fake
- Deterministic dummy-value generator for tests.