pub fn build_dfx_all(
workspace_root: &Path,
lock_relative_path: &str,
network: &str,
profile: WasmBuildProfile,
)Expand description
Build all dfx canisters while holding a file lock around the build.
pub fn build_dfx_all(
workspace_root: &Path,
lock_relative_path: &str,
network: &str,
profile: WasmBuildProfile,
)Build all dfx canisters while holding a file lock around the build.