pub fn wasm_path(
target_dir: &Path,
crate_name: &str,
profile: WasmBuildProfile,
) -> PathBufExpand description
Resolve the wasm artifact path for one crate under a target directory.
pub fn wasm_path(
target_dir: &Path,
crate_name: &str,
profile: WasmBuildProfile,
) -> PathBufResolve the wasm artifact path for one crate under a target directory.