pub struct WatchedInputSnapshot { /* private fields */ }Expand description
WatchedInputSnapshot
Implementations
Sourceimpl WatchedInputSnapshot
impl WatchedInputSnapshot
Sourcepub fn capture(
workspace_root: &Path,
watched_relative_paths: &[&str],
) -> Result<Self>
pub fn capture( workspace_root: &Path, watched_relative_paths: &[&str], ) -> Result<Self>
Capture the newest modification time across all watched inputs once.
Sourcepub fn artifact_is_fresh(self, artifact_path: &Path) -> Result<bool>
pub fn artifact_is_fresh(self, artifact_path: &Path) -> Result<bool>
Check whether one artifact is newer than the captured watched inputs.