pub struct CachedPicBaselineGuard<'a, T> { /* private fields */ }Expand description
CachedPicBaselineGuard
Methods from Deref<Target = CachedPicBaseline<T>>
Sourcepub fn restore(&self, controller_id: Principal)
pub fn restore(&self, controller_id: Principal)
Restore the captured snapshot set back into the owned PocketIC instance.
Sourcepub fn pic_mut(&mut self) -> &mut Pic
pub fn pic_mut(&mut self) -> &mut Pic
Mutably borrow the owned PocketIC instance behind this cached baseline.
Sourcepub fn metadata(&self) -> &T
pub fn metadata(&self) -> &T
Borrow the captured metadata associated with this cached baseline.
Sourcepub fn metadata_mut(&mut self) -> &mut T
pub fn metadata_mut(&mut self) -> &mut T
Mutably borrow the captured metadata associated with this cached baseline.