pub fn pic() -> PicExpand description
Create a fresh PocketIC universe.
IMPORTANT:
- Each call creates a new IC instance
- WARNING: DO NOT CACHE OR SHARE
PicACROSS TESTS - Reusing
Piccan retain global locks and background runtime state and can make later tests hang or fail nondeterministically - Required to avoid PocketIC wasm chunk store exhaustion